@@ -307,14 +307,18 @@ namespace lsvpd
 	 */
 	void DeviceTreeCollector::fillIBMVpd( Component* fillMe )
 	{
-		string path;
+		string path, vpdDataStr;
 		char *vpdData;
 		int size;
 
 		path = fillMe->deviceTreeNode.dataValue + "/ibm,vpd";
-		size = getBinaryData(path, &vpdData);
-		if (size == 0)
+		vpdDataStr = getBinaryData(path);
+		if ((size = vpdDataStr.length()) == 0)
 			return;
+
+		vpdData =  new char[size];
+		vpdDataStr.copy( vpdData, size );
+
 		parseVPDBuffer( fillMe, vpdData );
 
 		delete [] vpdData;
@@ -384,7 +388,8 @@ error:
 
 		type = *buf++;
 		if (type != OPAL_VPD_TYPE)
-			goto error;
+			return 0;
+
 		/* Read the size of the buffer */
 		size = *buf++;
 		size |= (*buf++) << 8;
@@ -397,12 +402,6 @@ error:
 
 		/* Total size of the buffer */
 		return size + 3;
-error:
-		Logger log;
-		ostringstream os;
-		os << "Attempting to parse VPD buffer of unsupported type " << (int)type;
-		log.log(os.str(), LOG_WARNING);
-		return 0;
 	}
 
 	unsigned int DeviceTreeCollector::parseVPDHeader( char *buf,
@@ -616,7 +615,6 @@ ERROR:
 	 */
 	void DeviceTreeCollector::cpyinto(Component *dest, Component *src)
 	{
-		vector<Component*>::iterator it, end;
 		vector<string> kids = src->getChildren( );
 		vector<string>::iterator vi, vend;
 
@@ -679,7 +677,6 @@ ERROR:
 	{
 		vector<string> kids = current->getChildren( );
 		vector<string>::iterator vi, vend;
-		vector<Component*>::iterator i, end;
 		Component *child, *parent;
 
 		for ( vi = kids.begin( ), vend = kids.end( ); vi != vend; ++vi ) {
@@ -732,18 +729,13 @@ ERROR:
 	Component * DeviceTreeCollector::findSCSIParent(Component *fillMe,
 							vector<Component*> devs)
 	{
-		string sysDev, devPath;
-		string parentSysFsName, pYL;
+		string sysDev;
 		vector<Component*>::iterator i, end;
 		const DataItem *devSpecific;
 		int loc;
 
 		devSpecific = fillMe->getDeviceSpecific("XB");
 		if (devSpecific != NULL) {
-			parentSysFsName = fillMe->devBus.dataValue
-				+ string("@")
-				+ devSpecific->dataValue;
-
 			sysDev = fillMe->sysFsLinkTarget.dataValue;
 			while (sysDev.length() > 1) {
 				if ((loc = sysDev.rfind("/", sysDev.length())) != (int) string::npos )
@@ -825,7 +817,7 @@ ERROR:
 
 	void DeviceTreeCollector::getRtasVPD(vector<Component*>& devs)
 	{
-		unsigned long int bufSize;
+		ssize_t bufSize;
 		char *rtasData = NULL;
 
 		bufSize = RtasCollector::rtasGetVPD("", &rtasData);
@@ -1160,13 +1152,17 @@ ERROR:
 		char *vpdData;
 		unsigned int size;
 		string sysVpd = string(OPAL_SYS_VPD_DIR) + string("/ibm,vpd");
+		string vpdDataStr;
 
 		getOpalSystemLocationCode( sys );
 
-		size = getBinaryData(sysVpd, &vpdData);
-		if (size == 0)
+		vpdDataStr = getBinaryData(sysVpd);
+		if ((size = vpdDataStr.length()) == 0)
 			return;
 
+		vpdData =  new char[size];
+		vpdDataStr.copy( vpdData, size );
+
 		parseSysVPD(vpdData, sys);
 		delete [] vpdData;
 	}
@@ -1185,7 +1181,7 @@ ERROR:
 	*/
 	void DeviceTreeCollector::fillSystem( System* sys )
 	{
-		string val = "";
+		string val;
 
 		sys->deviceTreeNode.setValue( "/proc/device-tree", 100,
 					      __FILE__, __LINE__);
