@@ -961,7 +961,6 @@ esc_subsystem_info:
 		const char *buf;
 		char buf2[512];
 		FILE *fi;
-		int i;
 
 		HelperFunctions::fs_fixPath(sysPath);
 		sysPath += "/devspec";
@@ -973,18 +972,18 @@ esc_subsystem_info:
 
 		// Read Results
 		fi = fopen(buf , "r");
-		if (fi != NULL) {
-			if (fgets(buf2, 512, fi) != NULL) {
-				i = 0;
-				while (buf2[i] != '\0') {
-					if (buf2[i] == '\n')
-						buf2[i] = '\0';
-					i++;
-				}
-			}
+		if (!fi)
+			return string("");
+
+		if (!fgets(buf2, sizeof(buf2), fi)) {
 			fclose(fi);
+			return string("");
 		}
 
+		if (buf2[strlen(buf2) - 1] == '\n')
+			buf2[strlen(buf2) - 1] = '\0';
+
+		fclose(fi);
 		// cleanup
 		return string(buf2);
 	}
@@ -1235,7 +1234,7 @@ esc_subsystem_info:
 			}
 		}
 
-		os.str(HelperFunctions::findAIXFSEntry(fillMe->getAIXNames(), "/dev"));
+		os.str(HelperFunctions::findAIXFSEntry(fillMe->getAIXNames(), "/dev/"));
 		struct hd_driveid id;
 		memset( &id, 0, sizeof( struct hd_driveid ) );
 		int fd = open( os.str( ).c_str( ), O_RDONLY | O_NONBLOCK );
@@ -1279,12 +1278,12 @@ esc_subsystem_info:
 	}
 
 	unsigned int SysFSTreeCollector::parsePciVPDBuffer( Component* fillMe,
-						    char *buf, int size )
+						    const char *buf, int size )
 	{
 		char key[ 3 ] = { '\0' };
 		/* Each VPD field will be at most 255 bytes long */
 		char val[ 256 ];
-		char *end;
+		const char *end;
 		unsigned char length;
 		uint16_t len;
 		string field;
@@ -1311,35 +1310,45 @@ esc_subsystem_info:
 		if (*buf != 0x82)
 			return 0;
 
+		end = buf + size;
+
 		/* Increment buffer to point to offset 1 to read Product
 		 * Name length
 		 */
 		buf++;
+		if (buf >= end)
+			return 0;
 
 		/* Data length is 2 bytes (byte 1 LSB, byte 2 MSB) */
 		len = *buf | (buf[1] << 8);
 
 		/* Increment buffer to point to read Product Name */
 		buf += 2;
+		if (buf >= end)
+			return 0;
 
 		/* Increment buffer to point to VPD R Tag */
 		buf += len;
+		if (buf >= end)
+			return 0;
 
 		/* Increment buffer to point to VPD R Tag data length */
 		buf++;
+		if (buf >= end)
+			return 0;
 
 		/* Increment buffer to point to first VPD keyword */
 		/* Increment by 2 because data length is of size 2 bytes */
 		buf += 2;
-
-		end = buf + size;
+		if (buf >= end)
+			return 0;
 
 		while( buf < end && *buf != 0x78 && *buf != 0x79 )
 		{
 			memset( key, '\0', 3 );
 			memset( val, '\0', 256 );
 
-			if( buf + 3 > end )
+			if( buf + 3 >= end )
 			{
 				goto ERROR;
 			}
@@ -1349,7 +1358,7 @@ esc_subsystem_info:
 			length = buf[ 2 ];
 			buf += 3;
 
-			if( buf + length > end )
+			if( buf + length >= end )
 			{
 				goto ERROR;
 			}
@@ -1364,27 +1373,27 @@ esc_subsystem_info:
 		return size;
 ERROR:
 		Logger logger;
-		logger.log( "Attempting to parse corrupt VPD buffer.", LOG_WARNING );
+		logger.log( "Attempting to parse corrupt VPD buffer.", LOG_NOTICE );
 		return 0;
 	}
 
 	/* Parse VPD file */
 	void SysFSTreeCollector::fillPciDevVpd( Component* fillMe )
 	{
-		char *vpdData;
 		int size;
-		string path;
+		string path, vpdDataStr;
 
 		path = fillMe->sysFsNode.getValue() + "/vpd";
 		if (HelperFunctions::file_exists(path) != true)
 			return;
 
-		size = getBinaryData(path, &vpdData);
-		if (size == 0)
+		vpdDataStr = getBinaryData(path);
+		if ((size = vpdDataStr.length()) == 0)
 			return;
 
-		parsePciVPDBuffer( fillMe, vpdData, size );
-		delete [] vpdData;
+		//Use data() and not c_str() as the binary data might
+		//contain '\0' characters.
+		parsePciVPDBuffer( fillMe, vpdDataStr.data(), size );
 	}
 
 	void SysFSTreeCollector::fillPCIDev( Component* fillMe,
@@ -1630,8 +1639,6 @@ ERROR:
 		string newDevDir;
 		bool dev_found = false;
 		int device_fd;
-		string dev_path;
-		string msg;
 
 		dev_syspath = fillMe->sysFsNode.getValue();
 		fsw.fs_getDirContents(dev_syspath, 'd', listing);
@@ -1677,17 +1684,12 @@ ERROR:
 		fillMe->devMinor = atoi(str.substr(beg, end).c_str());
 		fillMe->devAccessMode = S_IFBLK;
 
-		device_fd = device_open(fillMe->devMajor, fillMe->devMinor,
-					fillMe->devAccessMode, dev_path);
-		if (device_fd < 0) {
-			msg = string("vpdupdate: Failed opening device: ")
-				+ fillMe->idNode.getValue();
-			Logger().log( msg, LOG_WARNING );
+		device_fd = device_open(fillMe);
+		if (device_fd < 0)
 			return;
-		}
 
 		collectVpd(fillMe, device_fd, false);
-		device_close(device_fd, dev_path);
+		close(device_fd);
 		return;
 	}
 
